Package: specL
Type: Package
Title: specL - Prepare Peptide Spectrum Matches for Use in Targeted
        Proteomics
Version: 1.46.0
Authors@R: c(person("Christian", "Panse", 
        email = "cp@fgcz.ethz.ch",
        role = c("aut", "cre"),
        comment = c(ORCID = "0000-0003-1975-3064")),
    person("Jonas", "Grossmann",
        email = "jg@fgcz.ethz.ch",
	role = "aut",
	comment = c(ORCID = "0000-0002-6899-9020")),
    person("Christian", "Trachsel",
	role = "aut"),
    person("Witold E.", "Wolski",
	email = "wew@fgcz.ethz.ch",
	role = "ctb"))
Depends: R (>= 4.1), DBI (>= 0.5), methods (>= 3.3), protViz (>= 0.7),
        RSQLite (>= 1.1), seqinr (>= 3.3)
Suggests: BiocGenerics, BiocStyle (>= 2.2), knitr (>= 1.15), rmarkdown,
        RUnit (>= 0.4)
Description: provides a functions for generating spectra libraries that
        can be used for MRM SRM MS workflows in proteomics. The package
        provides a BiblioSpec reader, a function which can add the
        protein information using a FASTA formatted amino acid file,
        and an export method for using the created library in the
        Spectronaut software. The package is developed, tested and used
        at the Functional Genomics Center Zurich <https://fgcz.ch>.
License: GPL-3
URL: http://bioconductor.org/packages/specL/
Collate: read.bibliospec.R genSwathIonLib.R annotate.protein_id.R
        AllGenerics.R specL.R specLSet.R cdsw.R zzz.R
biocViews: MassSpectrometry, Proteomics
LazyData: true
BugReports: https://github.com/fgcz/specL/issues
VignetteBuilder: knitr
Config/pak/sysreqs: zlib1g-dev
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 12:40:12 UTC
RemoteUrl: https://github.com/bioc/specL
RemoteRef: RELEASE_3_23
RemoteSha: 4a57dea043e2e60cc7cd04cbdf9a05fbb5dce8bc
NeedsCompilation: no
Packaged: 2026-04-30 06:34:46 UTC; root
Author: Christian Panse [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1975-3064>),
  Jonas Grossmann [aut] (ORCID: <https://orcid.org/0000-0002-6899-9020>),
  Christian Trachsel [aut],
  Witold E. Wolski [ctb]
Maintainer: Christian Panse <cp@fgcz.ethz.ch>
Built: R 4.6.0; ; 2026-04-30 07:38:08 UTC; unix
