import("methods")
import("RSQLite")

importFrom("DBI", dbDriver)


importFrom("protViz", aa2mass)
importFrom("protViz", findNN)
importFrom("protViz", findNN_)
importFrom("protViz", fragmentIon)
importFrom("protViz", ssrc)
importFrom("protViz", lower_bound_)
importFrom("protViz", is.psmSet)


importFrom("seqinr", read.fasta)

importFrom("grDevices", "rainbow", "rgb")
importFrom("graphics", "abline", "barplot", "hist", "legend", "par",
               "points", "text")
importFrom("stats", "aggregate", "lm", "predict", "quantile")
importFrom("utils", "object.size", "write.table", "packageVersion")



export("read.bibliospec")
export("summary.psmSet")
export("plot.psmSet")
export("plot.psm")


export("annotate.protein_id")
export("genSwathIonLib")
export("cdsw")

exportClasses("specL", "specLSet")

exportMethods("show", "summary", "plot", 
    "write.spectronaut", "generate.consensus",
    "ionlibrary", "rt.input", "rt.normalized", 
    "merge.specLSet","getProteinPeptideTable")
