[![Build Status](https://travis-ci.org/fgcz/specL.svg?branch=master)](https://travis-ci.org/fgcz/specL)
[![doi](https://img.shields.io/badge/doi-10.1093%2Fbioinformatics%2Fbtv105-brightgreen)](https://doi.org/10.1093/bioinformatics/btv105)

# specL

prepare peptide spectrum matches for use in targeted proteomics using R and Bioconductor 

## Talks

- [Bioconductor European Developers Workshop, 2015-01-13, EMBL](http://fgcz-ms.uzh.ch/~cpanse/talks/specL_EuroBioc2015_Heidelberg.pdf)

