#R
# $HeadURL$
# $Id$
# $Date$


test_peptideStd <-
function(){
    # peptideStd[[133]]$peptideModSeq <- "YAM[+16.0]LDVLNTGAMIGQTLIDLTNK"
    # ionlibrary(L)[[133]]@group_id,  "YAM[+16.0]LDVLNTGAMIGQTLIDLTNK.3;837.765213"
}

#test_peptideStd()
